@@ -33,7 +33,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL.php,v 1.12 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL.php,v 1.13 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -41,7 +41,7 @@
 /**
  * С
  */
-define('SYL_VERSION', '0.8.2');
+define('SYL_VERSION', '0.8.3');
 
 /**
  * ١ǥ쥯ȥ
@@ -52,11 +52,11 @@ define('SYL_INCLUDE_DIR', SYL_DIR . '/include');
 /**
  * PHPƥ२顼¸ե饰
  */
-define('SYL_ERROR_SYSTEM_LOG', true);
+define('SYL_LOG_SYSTEM_ERROR', true);
 /**
  * PHPƥ२顼¸ե
  */
-define('SYL_ERROR_SYSTEM_LOG_FILE', SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log');
+define('SYL_LOG_SYSTEM_ERROR_FILE', SYL_DIR . '/var/syslogs/phperror_' . date('Ymd') . '.log');
 
 /**
  * ǥХå٥
