@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.14 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.15 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -43,9 +43,9 @@ set_magic_quotes_runtime(0);
 /**
  * PHPƥ२顼¸
  */
-if (SYL_ERROR_SYSTEM_LOG && is_writable(dirname(SYL_ERROR_SYSTEM_LOG_FILE))) {
-    ini_set('log_errors', SYL_ERROR_SYSTEM_LOG);
-    ini_set('error_log', SYL_ERROR_SYSTEM_LOG_FILE);
+if (SYL_LOG_SYSTEM_ERROR && is_writable(dirname(SYL_LOG_SYSTEM_ERROR_FILE))) {
+    ini_set('log_errors', SYL_LOG_SYSTEM_ERROR);
+    ini_set('error_log', SYL_LOG_SYSTEM_ERROR_FILE);
 }
 
 /**
@@ -74,7 +74,7 @@ define('SYL_CONTROLLER_NAME', 'controller');
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.14 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.15 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
