@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.12 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.13 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.12 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.13 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -129,8 +129,16 @@ class SyL_View
                 $class_name = 'SyL_ViewSmarty';
                 $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
                 break;
+            case 'js':
+                $class_name = 'SyL_ViewJs';
+                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
+                break;
+            case 'ajax':
+                $class_name = 'SyL_ViewAjax';
+                $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
+                break;
             case 'json':
-                $class_name = 'SyL_ViewJsJson';
+                $class_name = 'SyL_ViewJson';
                 $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
                 break;
             case 'default':
@@ -216,6 +224,21 @@ class SyL_View
         return $values;
     }
 
+    /**
+     * ӥ塼ɽ󥯥롼ɥե
+     * 
+     * @access public
+     * @return array ӥ塼ɽ󥯥롼ɥե
+     */
+    function getIncludeFiles()
+    {
+        if (isset($this->config['includes']) && is_array($this->config['includes'])) {
+            return array_map(create_function('$a', 'return "' . $this->dm->getActionDir() . '/" . $a;'), $this->config['includes']);
+        } else {
+            return array();
+        }
+    }
+
     /**
      * HTML󥰼¹
      * 
