@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.2 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJs.php,v 1.2 2007/02/03 11:44:45 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJs.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJs extends SyL_View
@@ -62,32 +62,15 @@ class SyL_ViewJs extends SyL_View
     function render()
     {
         $request =& SyL_Request::getInstance();
-        $mode = $request->getParameter('mode');
-        $modes = array();
-        if ($mode) {
-            $modes = explode(',', $mode);
-        } else {
-            $modes = array();
-        }
 
-        $session =& $request->getSessionObject();
-
-        include_once SYL_INCLUDE_DIR . '/lib/SyL_AjaxClient.php';
-        $ajaxjs =& new SyL_AjaxClient();
-        $ajaxjs->setSessionId($session->getSidQuery());
-        $ajaxjs->setUrl($_SERVER['PHP_SELF']);
-        $ajaxjs->setActionKey(SYL_ACTION_KEY);
-        foreach ($modes as $mode) {
-            $method = 'is' . ucfirst($mode);
-            if (method_exists($ajaxjs, $method)) {
-                $ajaxjs->$method(true);
-            }
-        }
+        include_once SYL_INCLUDE_DIR . '/lib/SyL_Js.php';
+        $js =& new SyL_Js();
+        $js->setImport($request->getParameter('import'));
 
         // JavaScirptƥĥ
         SyL_Response::setHeader('Content-Type', 'application/x-javascript; charset=' . SYL_ENCODE_INTERNAL);
         // JavaScirpt
-        $this->setRender($ajaxjs->getJs());
+        $this->setRender($js->getJs());
     }
 }
 
