@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.1 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewJson.php,v 1.1 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewJson.php,v 1.3 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewJson extends SyL_View
@@ -61,30 +61,23 @@ class SyL_ViewJson extends SyL_View
      */
     function render()
     {
-        $content_type = '';
-        $javascript   = '';
+        // JavaScirptƥĥ
+        SyL_Response::setHeader('Content-Type', 'application/json; charset=' . SYL_ENCODE_AJAX);
         if ($this->dm->getActionName() != '') {
             // ѥ᡼ϡJson֥Ȥ򥻥å
             if (!function_exists('json_encode')) {
                 include_once SYL_INCLUDE_DIR . '/lib/SyL_Json.php';
             }
-            $content_type = 'application/json; charset=' . SYL_ENCODE_AJAX;
             $values     =& $this->getActionValues();
             $javascript = json_encode($values);
             $javascript = mb_convert_encoding($javascript, SYL_ENCODE_AJAX, SYL_ENCODE_INTERNAL);
-        } else {
-            $content_type = 'application/x-javascript; charset=' . SYL_ENCODE_INTERNAL;
-            include_once SYL_INCLUDE_DIR . '/lib/SyL_AjaxJs.php';
-            $ajaxjs =& new SyL_AjaxJs();
-            $ajaxjs->setUrl($_SERVER['PHP_SELF']);
-            $ajaxjs->setActionKey(SYL_ACTION_KEY);
-            $javascript = $ajaxjs->getJs();
-        }
 
-        // JavaScirptƥĥ
-        SyL_Response::setHeader('Content-Type', $content_type);
-        // JavaScirpt
-        $this->setRender($javascript);
+            // JavaScirpt
+            $this->setRender($javascript);
+        } else {
+            // Ϥʤ
+            $this->setRender('');
+        }
     }
 }
 
