@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.1 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.2 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -39,7 +39,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.1 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_ViewLayoutDefault.php,v 1.2 2007/02/12 10:39:51 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_ViewLayoutDefault extends SyL_View
@@ -71,6 +71,11 @@ class SyL_ViewLayoutDefault extends SyL_View
             }
         }
 
+        // ӥ塼ɽ󥯥롼ɥե
+        foreach ($this->getIncludeFiles() as $include_file) {
+            include_once $include_file;
+        }
+
         // ƥץ졼ȼ
         $template_file = $this->getTemplateDir() . $this->getTemplateFile();
 
