@@ -27,13 +27,13 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XMLParser.php,v 1.11 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XMLParser.php,v 1.12 2007/02/03 11:44:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
 
-if (!defined('SYL_XML_ENCODE')) {
-    define('SYL_XML_ENCODE', 'UTF-8');
+if (!defined('SYL_ENCODE_XML')) {
+    define('SYL_ENCODE_XML', 'UTF-8');
 }
 
 /**
@@ -43,7 +43,7 @@ if (!defined('SYL_XML_ENCODE')) {
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_XMLParser.php,v 1.11 2007/01/21 08:13:15 seasonstream Exp $
+ * @version   CVS: $Id: SyL_XMLParser.php,v 1.12 2007/02/03 11:44:45 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_XMLParser
@@ -61,7 +61,7 @@ class SyL_XMLParser
      * @access private
      * @var string
      */
-    var $xml_encode = SYL_XML_ENCODE;
+    var $xml_encode = SYL_ENCODE_XML;
 
     /**
      * 󥹥ȥ饯
